@@ -118,7 +118,7 @@ class TrustScore(object):
 
         # make sure Y represents predicted classes, not one-hot encodings
         if len(Y.shape) > 1:
-            Y = np.argmax(Y, axis=1)
+            Y = np.argmax(Y, axis=1)  # type: ignore
 
         if self.filter == 'probability_knn':
             X_filter, Y_filter = self.filter_by_probability_knn(X, Y)
@@ -165,7 +165,7 @@ class TrustScore(object):
         """
         # make sure Y represents predicted classes, not probabilities
         if len(Y.shape) > 1:
-            Y = np.argmax(Y, axis=1)
+            Y = np.argmax(Y, axis=1)  # type: ignore
 
         # KDTree needs 2D data
         if len(X.shape) > 2:
