@@ -83,6 +83,12 @@ class ALE(Explainer):
         self.extrapolate_constant_perc = extrapolate_constant_perc
         self.extrapolate_constant_min = extrapolate_constant_min
 
+        self.meta['params'].update(check_feature_resolution=check_feature_resolution,
+                                   low_resolution_threshold=low_resolution_threshold,
+                                   extrapolate_constant=extrapolate_constant,
+                                   extrapolate_constant_perc=extrapolate_constant_perc,
+                                   extrapolate_constant_min=extrapolate_constant_min)
+
     def explain(self, X: np.ndarray, features: List[int] = None, min_bin_points: int = 4) -> Explanation:
         """
         Calculate the ALE curves for each feature with respect to the dataset `X`.
@@ -116,8 +122,8 @@ class ALE(Explainer):
             pred = np.atleast_2d(self.predictor(X[0].reshape(1, -1)))
             n_targets = pred.shape[1]
             self.target_names = [f'c_{i}' for i in range(n_targets)]
-        self.feature_names = np.array(self.feature_names)
-        self.target_names = np.array(self.target_names)
+        self.feature_names = np.array(self.feature_names)  # type: ignore
+        self.target_names = np.array(self.target_names)  # type: ignore
 
         # only calculate ALE for the specified features and return the explanation for this subset
         if features:
