@@ -411,7 +411,11 @@ class IntegratedGradients(Explainer):
         if layer is None:
             layer_num = 0
         else:
-            layer_num = model.layers.index(layer)
+            try:
+                layer_num = model.layers.index(layer)
+            except ValueError:
+                logger.info("Layer not in the list of model.layers")
+                layer_num = None
 
         params['layer'] = layer_num
         self.meta['params'].update(params)
@@ -549,6 +553,10 @@ class IntegratedGradients(Explainer):
 
         return Explanation(meta=copy.deepcopy(self.meta), data=data)
 
+    def reset_predictor(self, predictor: Union[tf.keras.Model, 'keras.Model']) -> None:
+        # TODO: check what else should be done (e.g. validate dtypes again?)
+        self.model = predictor
+
     def _compute_attributions_list_input(self,
                                          X: List[np.ndarray],
                                          baselines: Union[List[int], List[float], List[np.ndarray]],
@@ -587,10 +595,10 @@ class IntegratedGradients(Explainer):
         # define paths in features' space
         paths = []
         for i in range(len(X)):
-            x, baseline = X[i], baselines[i]
+            x, baseline = X[i], baselines[i]  # type: ignore
             # format and check baselines
             baseline = _format_input_baseline(x, baseline)
-            baselines[i] = baseline
+            baselines[i] = baseline  # type: ignore
 
             # construct paths
             path = np.concatenate([baseline + alphas[i] * (x - baseline) for i in range(self.n_steps)], axis=0)
@@ -664,7 +672,7 @@ class IntegratedGradients(Explainer):
                                              target, target_paths,
                                              self.n_steps, nb_samples,
                                              step_sizes, j)
-                norm = X[j] - baselines[j]
+                norm = X[j] - baselines[j]  # type: ignore
 
                 attribution = norm * sum_int
                 attributions.append(attribution)
